/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * CVfast_data.cpp
 *
 * Code generation for function 'CVfast_data'
 *
 */

/* Include files */
#include "rt_nonfinite.h"
#include "CVfast.h"
#include "MAVEfast.h"
#include "CVfast_data.h"

/* Variable Definitions */
unsigned int state[625];
//omp_nest_lock_t emlrtNestLockGlobal;

/* End of code generation (CVfast_data.cpp) */
